@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.008003;
 
-our $VERSION = '1.606';
+our $VERSION = '1.607';
 
 use Term::Choose::Constants qw( :screen :linux );
 
@@ -14,10 +14,6 @@ BEGIN {
     if ( eval { require Term::ReadKey; 1 } ) {
         $Term_ReadKey = 1;
     }
-    #else {
-    #    require Time::HiRes;
-    #    Time::HiRes->import( 'time' );
-    #}
 }
 my $Stty = '';
 
@@ -33,14 +29,6 @@ sub _getc_wrapper {
         return Term::ReadKey::ReadKey( $timeout );
     }
     else {
-        #if ( $timeout && $timeout > 0 ) { #
-        #    my $starttime = time;
-        #    my $endtime = $starttime + $timeout;
-        #    while ( time < $endtime ) {
-        #        my $value = getc();
-        #        return $value if defined $value;
-        #    }
-        #}
         return getc();
     }
 }
@@ -83,8 +71,8 @@ sub __get_key_OS {
             elsif ( $c3 =~ m/^[0-9]$/ ) {
                 my $c4 = _getc_wrapper( 0 );
                 if ( $c4 eq '~' ) {
-                    if    ( $c3 eq '2' ) { return VK_INSERT; } # unused
-                    elsif ( $c3 eq '3' ) { return VK_DELETE; } # unused
+                    if    ( $c3 eq '2' ) { return VK_INSERT; }
+                    elsif ( $c3 eq '3' ) { return VK_DELETE; }
                     elsif ( $c3 eq '5' ) { return VK_PAGE_UP; }
                     elsif ( $c3 eq '6' ) { return VK_PAGE_DOWN; }
                     else {
